/* Copyright (c) 2019  Joe Hacker <joe@example.com>
 *
 * This file is part of skeletonmm.
 *
 * skeletonmm is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 2.1 of the License,
 * or (at your option) any later version.
 *
 * skeletonmm is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SKELETONMM_H_INCLUDED
#define SKELETONMM_H_INCLUDED

/** @mainpage skeletonmm Reference Manual
 *
 * @section description Description
 *
 * The skeletonmm C++ binding provides a C++ interface on top of the skeleton
 * C library.
 *
 * @section overview Overview
 *
 * [...]
 *
 * @section use Use
 *
 * To use skeletonmm in your C++ application, include the central header file
 * <tt>\<skeletonmm.h\></tt>.  The skeletonmm package ships a @c pkg-config
 * file with the correct include path and link command-line for the compiler.
 */

#include <skeletonmmconfig.h>
#include <skeletonmm/skeleton.h>

/** @example example/example.cc
 * A skeletonmm example program.
 */

#endif /* !SKELETONMM_H_INCLUDED */
